OSSP CVS Repository

ossp - Difference in ossp-pkg/sio/sio_hello.c versions 1.6 and 1.7
Not logged in
[Honeypot]  [Browse]  [Home]  [Login]  [Reports
[Search]  [Ticket]  [Timeline
  [History

ossp-pkg/sio/sio_hello.c 1.6 -> 1.7

--- sio_hello.c  2002/11/08 11:12:28     1.6
+++ sio_hello.c  2002/11/14 15:56:10     1.7
@@ -5,7 +5,6 @@
 
 #include "al.h"
 #include "sio.h"
-#include "sio_module.h"
 
 #define PROMPT "Login: "
 #define NPROMPT (sizeof(PROMPT)-1)
@@ -274,9 +273,9 @@
         my->isoutput = isoutput;
 
         if (isoutput) {
-            GOTO(PROMPTING, SIO_LOOP);
+            GOTO(PROMPTING, SIO_SCHED_LOOP);
         } else {
-            GOTO(PROMPTING, SIO_XSTREAM);
+            GOTO(PROMPTING, SIO_SCHED_CROSS);
         }
         break;
 
@@ -287,13 +286,13 @@
          *  only called on output stream
          *
          *  either fall through from INIT as writer
          *  or scheduled via SIO_XSTREAM from reader
          *  maybe there should be a SIO_STAY ?
          *
          *  send prompt string, schedule upstream
          */
         hello_sendprompt(my);
-        GOTO(PROMPTED, SIO_UPSTREAM);
+        GOTO(PROMPTED, SIO_SCHED_UP);
         break;
 
 
@@ -308,9 +307,9 @@
          *
          */
         if (al_bytes(my->al_out) > 0)
-            GOTO(PROMPTED, SIO_UPSTREAM);
+            GOTO(PROMPTED, SIO_SCHED_UP);
         else
-            GOTO(WAIT, SIO_XSTREAM);
+            GOTO(WAIT, SIO_SCHED_CROSS);
         break;
 
     case WAIT:
@@ -336,23 +335,23 @@
          *
          */
         if (!hello_readpasswd(my))
-            GOTO(WAIT, SIO_UPSTREAM);
+            GOTO(WAIT, SIO_SCHED_UP);
         else {
             good = my->npass == NPASS &&
                    memcmp(my->passwd, PASSWD, NPASS) == 0;
             if (!good) {
                 hello_dropsaved(my);
                 if (isoutput != my->isoutput) {
-                    GOTO(BAD, SIO_XSTREAM);
+                    GOTO(BAD, SIO_SCHED_CROSS);
                 } else {
-                    GOTO(BAD, SIO_LOOP);
+                    GOTO(BAD, SIO_SCHED_LOOP);
                 }
             } else {
                 hello_restore(my);
                 if (isoutput != my->isoutput) {
-                    GOTO(GOOD, SIO_XSTREAM);
+                    GOTO(GOOD, SIO_SCHED_CROSS);
                 } else
-                    GOTO(GOOD, SIO_LOOP);
+                    GOTO(GOOD, SIO_SCHED_LOOP);
             }
         }
         break;
@@ -383,7 +382,7 @@
         else
             hello_writeeof(my);
 
-        GOTO(BAD, SIO_DOWNSTREAM);
+        GOTO(BAD, SIO_SCHED_DOWN);
         break;
     }
 
@@ -287,13 +286,13 @@
          *
          *  either fall through from INIT as writer
-         *  or scheduled via SIO_XSTREAM from reader
+         *  or scheduled via SIO_SCHED_CROSS from reader
          *  maybe there should be a SIO_STAY ?
          *

CVSTrac 2.0.1